=======
Credits
=======

Development Lead
----------------

* Simon Birrer <sibirrer@gmail.com> `sibirrer <https://github.com/sibirrer/>`_


Key contributors
----------------
* Anowar Shajib `ajshajib <https://github.com/ajshajib/>`_
* Aymeric Galan `aymgal <https://github.com/aymgal/>`_
* Daniel Gilman `dangilman <https://github.com/dangilman/>`_


Contributors (alphabetic)
-------------------------

* Jelle Aalbers `JelleAalbers <https://github.com/JelleAalbers>`_
* Joel Akeret `jakeret <https://github.com/jakeret/>`_
* Adam Amara `aamara <https://github.com/aamara/>`_
* Xuheng Ding `dartoon <https://github.com/dartoon/>`_
* Sydney Erickson `smericks <https://github.com/smericks/>`_
* Kevin Fusshoeller
* Matthew R. Gomer `mattgomer <https://github.com/mattgomer>`_
* Felix A. Kuhn
* Felix Mayor
* Martin Millon `martin-millon <https://github.com/martin-millon/>`_
* Robert Morgan `rmorgan10 <https://github.com/rmorgan10/>`_
* Anna Nierenberg `amn3142 <https://github.com/amn3142/>`_
* Brian Nord `bnord <https://github.com/bnord/>`_
* Giulia Pagano
* Ji Won Park `jiwoncpark <https://github.com/jiwoncpark/>`_
* Andreas Filipp `andreasfilipp <https://github.com/andreasfilipp/>`_
* Thomas Schmidt `Thomas-01 <https://github.com/Thomas-01/>`_
* Dominique Sluse
* Luca Teodori `lucateo <https://github.com/lucateo/>`_
* Nicolas Tessore `ntessore <https://github.com/ntessore/>`_
* Madison Ueland `mueland <https://github.com/mueland/>`_
* Lyne Van de Vyvere `LyneVdV <https://github.com/LyneVdV/>`_
* Sebastian Wagner-Carena `swagnercarena <https://github.com/swagnercarena>`_
* Cyril Welschen
* Ewoud Wempe `ewoudwempe <https://github.com/ewoudwempe/>`_
* Lilan Yang `ylilan <https://github.com/ylilan/>`_
* Zhiyuan Ma `Jerry-Ma <https://github.com/Jerry-Ma/>`_
